@@ -2,6 +2,9 @@ package NewSubst ;
  
 use Filter::Util::Call ;
 use Carp ;
+
+use strict ;
+use warnings ;
  
 sub import
 {
