@@ -2,6 +2,9 @@ package Count ;
  
 use Filter::Util::Call ;
  
+use strict ;
+use warnings ;
+
 sub filter
 {
     my ($self) = @_ ;
